Adobe Analytics for Team ACT v.0.0.1
==============

This module has been built to provide a better environment specifically for adobe analysts in Team ACT.</br></br>

This module itself would not contain any confidential information & nor is incapable of retrieving any data unless the correct API credential is given.
The guide of pulling data will be only provided internally, no inquires will be accepted from outsiders.

  
## Functionalities


* Retrieve Daily, Weekly, Monthly data and automatically dumps into the DB connected in their local machine.
* Capable up to 2nd breakdown.
* Automatically retrieves data of all Reporting Suites.<br/><br/>

More functionalities will be added in sooner time.<br/><br/>
